@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::KENTNL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.0.2';
+  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.0.3';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
@@ -170,6 +170,7 @@ sub bundle_config {
     ],
 
     [ 'MetaData::BuiltWith'  => { show_uname => 1, uname_args => q{ -s -o -r -m -i } } ],
+    [ 'CPANChangesTests'     => {} ],
     [ 'CompileTests'         => {} ],
     [ 'CriticTests'          => {} ],
     [ 'MetaTests'            => {} ],
@@ -187,7 +188,7 @@ sub bundle_config {
       [
         _release_fail($arg),
         _only_git( $arg, [ 'Git::Check' => { filename => 'Changes' } ] ),
-        [ 'NextRelease' => {} ],
+        [ 'NextRelease' => { time_zone => 'UTC', format => q[%-9v %{yyyy-MM-dd'T'HH:mm:ss}dZ] } ],
         _only_git( $arg, [ [ 'Git::Tag', 'tag_master' ] => { tag_format => '%v-source' } ] ),
         _only_git( $arg, [ 'Git::Commit' => {} ] ),
         _only_git( $arg, [ 'Git::CommitBuild' => { release_branch => 'releases' } ] ),
@@ -216,7 +217,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 1.0.2
+version 1.0.3
 
 =head1 SYNOPSIS
 
